==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextServicesSupport__24BCSSChild.h <==
// public class java.beans.beancontext.BeanContextServicesSupport$BCSSChild

// class file dependencies
// @dep_class ad017f23f6205dcd java_beans_beancontext_BeanContextServicesSupport__24BCSSChild
// @dep_class 861a03e0754f962b java_beans_beancontext_BeanContextSupport__24BCSChild
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextSupport__24BCSChild

#include "java/beans/beancontext/BeanContextSupport__24BCSChild.h"

#ifndef _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild_H_
#define _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServicesSupport$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object;

typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$method$_init$a7185a17cd67eb90(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object *, struct _jc_java_beans_beancontext_BeanContextServicesSupport$object *);

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods {
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods	java_beans_beancontext_BeanContextSupport__24BCSChild;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods	java_beans_beancontext_BeanContextServicesSupport__24BCSSChild;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs {
	struct _jc_java_beans_beancontext_BeanContextServicesSupport$object	*this;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs {
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs	java_beans_beancontext_BeanContextServicesSupport__24BCSSChild;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs	java_beans_beancontext_BeanContextSupport__24BCSChild;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs	java_beans_beancontext_BeanContextSupport__24BCSChild;
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs	java_beans_beancontext_BeanContextServicesSupport__24BCSSChild;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object {
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServicesSupport__24BCSSChild, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextServicesSupport__24BCSSChild.h <==
// public class java.beans.beancontext.BeanContextServicesSupport$BCSSChild

// class file dependencies
// @dep_class ad017f23f6205dcd java_beans_beancontext_BeanContextServicesSupport__24BCSSChild
// @dep_class 861a03e0754f962b java_beans_beancontext_BeanContextSupport__24BCSChild
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextSupport__24BCSChild

#include "java/beans/beancontext/BeanContextSupport__24BCSChild.h"

#ifndef _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild_H_
#define _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServicesSupport$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object;

typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$fields_struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$method$_init$a7185a17cd67eb90(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object *, struct _jc_java_beans_beancontext_BeanContextServicesSupport$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods {
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods	java_beans_beancontext_BeanContextSupport__24BCSChild;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vmethods	java_beans_beancontext_BeanContextServicesSupport__24BCSSChild;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs {
	struct _jc_java_beans_beancontext_BeanContextServicesSupport$object	*this;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs {
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_refs	java_beans_beancontext_BeanContextServicesSupport__24BCSSChild;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs	java_beans_beancontext_BeanContextSupport__24BCSChild;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs	java_beans_beancontext_BeanContextSupport__24BCSChild;
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$sub_nonrefs	java_beans_beancontext_BeanContextServicesSupport__24BCSSChild;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$object {
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$vtype _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServicesSupport__24BCSSChild, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSChild_H_ */
